aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-gvrp.c
diff options
context:
space:
mode:
Diffstat (limited to 'epan/dissectors/packet-gvrp.c')
-rw-r--r--epan/dissectors/packet-gvrp.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/epan/dissectors/packet-gvrp.c b/epan/dissectors/packet-gvrp.c
index d20d2fe489..989f5f3f78 100644
--- a/epan/dissectors/packet-gvrp.c
+++ b/epan/dissectors/packet-gvrp.c
@@ -4,8 +4,8 @@
*
* $Id$
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
* Copyright 1998 Gerald Combs
*
* This program is free software; you can redistribute it and/or
@@ -132,7 +132,7 @@ dissect_gvrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
if (protocol_id != GARP_DEFAULT_PROTOCOL_ID)
{
proto_tree_add_text(gvrp_tree, tvb, GARP_PROTOCOL_ID, sizeof(guint16),
- " (Warning: this version of Ethereal only knows about protocol id = 1)");
+ " (Warning: this version of Wireshark only knows about protocol id = 1)");
call_dissector(data_handle,
tvb_new_subset(tvb, GARP_PROTOCOL_ID + sizeof(guint16), -1, -1),
pinfo, tree);
@@ -295,7 +295,7 @@ dissect_gvrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
}
/* Register the protocol with Ethereal */
void
proto_register_gvrp(void)
{
@@ -4,8 +4,8 @@
* $Id$
*
- * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@ethereal.com>
+ * Wireshark - Network traffic analyzer
+ * By Gerald Combs <gerald@wireshark.org>
* Copyright 1998 Gerald Combs
*
@@ -295,7 +295,7 @@ dissect_gvrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
}
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
void
proto_register_gvrp(void)